Crate specta_util

source ·
TODO

Macros

  • Specta compatible selection of struct fields.

Structs

  • Anyserde
    Easily convert a non-Specta type into a Specta compatible type. This will be typed as any in Typescript.
  • Define a set of types which can be exported together
  • Unknownserde
    Easily convert a non-Specta type into a Specta compatible type. This will be typed as unknown in Typescript.

Functions

  • exportexport
    Get the global type store containing all registered types.