Function specta_util::export
source · pub fn export() -> TypeCollectionAvailable on crate feature
export only.Expand description
Get the global type store containing all registered types.
pub fn export() -> TypeCollectionexport only.Get the global type store containing all registered types.