Struct specta_util::TypeCollection

source ·
pub struct TypeCollection { /* private fields */ }
Define a set of types which can be exported together

Implementations

source

impl TypeCollection

source

pub fn extend(&mut self, collection: impl Borrow<TypeCollection>) -> &mut Self

Join another type collection into this one.

source

pub fn register<T: NamedType>(&mut self) -> &mut Self

Register a type with the collection.

source

pub fn collect(&self, type_map: &mut TypeMap)

Export all the types in the collection into the given type map.

source

pub fn export<L: Language>(&self, language: L) -> Result<String, L::Error>

TODO

source

pub fn export_to<L: Language>( &self, language: L, path: impl AsRef<Path>, ) -> Result<(), L::Error>

TODO